@@ -8,28 +8,6 @@ NULL
 # dplyr::one_of is what is causing us to depend on dplyr (>= 0.5.0)
 
 
-#' Rename a column
-#'
-#' @param .data data object to work on
-#' @param newName character new column name
-#' @param oldName character old column name
-#'
-#' @examples
-#'
-#' d <- data.frame(Sepal_Length= c(5.8,5.7),
-#'                 Sepal_Width= c(4.0,4.4),
-#'                 Species= 'setosa', rank=c(1,2))
-#' replyr_rename(d, 'family', 'Species')
-#'
-#' @export
-#'
-replyr_rename <- function(.data, newName, oldName) {
-  if(newName!=oldName) {
-    # use setNames here so this code is independent of let
-    return(dplyr::rename_(.data,.dots=stats::setNames(oldName, newName)))
-  }
-  .data
-}
 
 #' Map names of columns to known values and drop other columns.
 #'
@@ -101,7 +79,7 @@ replyr_mapRestrictCols <- function(x,nmap,reverse=FALSE) {
     if(nchar(ni)<=0) {
       stop('replyr::replyr_mapRestrictCols nmap keys must not be empty strings')
     }
-    if(!wrapr:::isValidAndUnreservedName(ni)) {
+    if(!isValidAndUnreservedName(ni)) {
       stop(paste('replyr:replyr_mapRestrictCols nmap key not a valid name: "',ni,'"'))
     }
     ti <- nmap[[ni]]
@@ -117,7 +95,7 @@ replyr_mapRestrictCols <- function(x,nmap,reverse=FALSE) {
     if(nchar(ti)<=0) {
       stop('replyr::replyr_mapRestrictCols nmap values must not be empty strings')
     }
-    if(!wrapr:::isValidAndUnreservedName(ti)) {
+    if(!isValidAndUnreservedName(ti)) {
       stop(paste('replyr:replyr_mapRestrictCols nmap value not a valid name: "',ti,'"'))
     }
     if(ti!=ni) {
